@@ -14,15 +14,11 @@ def save(ctx, message, push):
 
     # Recover repo from context
     repo = ctx.obj['REPO']
+    conflicted_files = get_conflict_files(repo)
+
+    if not conflicted_files:
 
-    try:
-        repo.git.diff("--check")
-    except GitCommandError as e:
-        click.echo("Please fix the following conflicts before saving")
-        click.echo(e.stdout.split("'")[1])
-    else: 
         #git add .
-        #En teoría esto no agrega .git, queda probar
         if not message:
             message = click.prompt('Commit message')
     
@@ -38,26 +34,25 @@ def save(ctx, message, push):
             if repo.remotes.origin.exists():
                 try:
                     repo.git.pull()
-                except Exception as e:
-                    #click.echo(type(e))
-                    #click.echo(e.args)
-                    error_array = find_conflict(repo)
-                    # We'll use this as a flag to determine whether we found any files with conflicts
-                    #found_a_conflict = find_conflict(repo)
+                except :
+                    conflicted_files_merge = conflicts_from_merge(repo)
 
-                    if error_array:
+                    if conflicted_files_merge:
                         click.echo('Merge conflicts in:')
-                        for error in error_array: 
-                            click.echo("- " + error)
+                        for conflict_file in conflicted_files_merge: 
+                            click.echo("- " + conflict_file)
                         click.echo('Please fix conflicts then use "gt save -p" again')    
                 else:
                     repo.git.push()
 
             else:
                 click.echo('Remote repository does not exist!')
+    else:
+        click.echo('Please fix the following conflicts then use "gt save -p" again')
+        for conflicted_file in conflicted_files:
+            click.echo(conflicted_file)
 
-def find_conflict(repo):
-    # This gets the dictionary discussed above 
+def conflicts_from_merge(repo):
     unmerged_blobs = repo.index.unmerged_blobs()
     error_array = []
     # We're really interested in the stage each blob is associated with.
@@ -71,3 +66,11 @@ def find_conflict(repo):
                 if path not in error_array:
                     error_array.append(path)
     return error_array
+
+def get_conflict_files(repo):
+    matched_lines=[]
+    try:
+        repo.git.diff("--check")
+    except GitCommandError as e:
+        matched_lines = [line for line in e.stdout.split("'")[1].split('\n') if "conflict" in line]
+    return matched_lines
\ No newline at end of file
